@@ -170,8 +170,7 @@ class Application(Gtk.Application):
 
     def do_startup(self):
         """
-            Add startup notification and
-            build gnome-shell menu after Gtk.Application startup
+            Init application
         """
         Gtk.Application.do_startup(self)
         Notify.init("Lollypop")
@@ -242,7 +241,7 @@ class Application(Gtk.Application):
                 playlist_ids = self.player.get_user_playlist_ids()
             dump(playlist_ids,
                  open(DataPath + "/playlist_ids.bin", "wb"))
-        if self.player.is_playing():
+        if self.player.current_track.id is not None:
             position = self.player.position
         else:
             position = 0
