@@ -75,13 +75,20 @@ class CellRendererArtist(Gtk.CellRendererText):
             self.rowid >= 0 and\
             Lp().settings.get_value('artist-artwork')
         if draw_artwork:
-            cell_area.width -= ArtSize.ARTIST_SMALL
-            cell_area.x = ArtSize.ARTIST_SMALL + self.xshift * 2
+            if Gtk.Widget.get_default_direction() == Gtk.TextDirection.LTR:
+                cell_area.x = ArtSize.ARTIST_SMALL + self.xshift * 2
+                cell_area.width -= ArtSize.ARTIST_SMALL
+            else:
+                cell_width = cell_area.width + cell_area.x
+                cell_area.width -= ArtSize.ARTIST_SMALL + self.xshift
         Gtk.CellRendererText.do_render(self, ctx, widget,
                                        cell_area, cell_area, flags)
         if draw_artwork:
+            if Gtk.Widget.get_default_direction() == Gtk.TextDirection.LTR:
+                cell_area.x = self.xshift
+            else:
+                cell_area.x = cell_width - ArtSize.ARTIST_SMALL
             cell_area.width = ArtSize.ARTIST_SMALL
-            cell_area.x = self.xshift
             self.do_own_render(ctx, widget, cell_area, size)
 
     def do_own_render(self, ctx, widget, cell_area, size):
