@@ -69,6 +69,14 @@ class GstPlayFlags:
     GST_PLAY_FLAG_TEXT = 1 << 3   # We want subtitle output
 
 
+class Loading:
+    NONE = 0
+    LEFT = 1
+    RIGHT = 2
+    ALL = 3
+    STOP = 4
+
+
 class ArtSize:
     SMALL = 33
     MEDIUM = 48  # If changed, adapt width request in AlbumRow
