@@ -57,9 +57,9 @@ class FullScreen(Gtk.Window, InfosController,
         # We want 500 and 200 in full hd
         scale = self.get_scale_factor()
         if geometry.width > geometry.height:
-            artsize = int(ArtSize.MONSTER*geometry.width/1920/scale)
+            artsize = int(ArtSize.FULLSCREEN*geometry.width/1920/scale)
         else:
-            artsize = int(ArtSize.MONSTER*geometry.height/1920/scale)
+            artsize = int(ArtSize.FULLSCREEN*geometry.height/1920/scale)
         InfosController.__init__(self, artsize)
 
         self._play_btn = builder.get_object('play_btn')
