@@ -34,7 +34,6 @@ class MiniPlayer(Gtk.Bin, InfosController):
         self._grid = builder.get_object('grid')
         self._title_label = builder.get_object('title')
         self._artist_label = builder.get_object('artist')
-        self._cover_frame = builder.get_object('frame')
         self._cover = builder.get_object('cover')
         self._signal_id = Lp().player.connect('current-changed',
                                               self.on_current_changed)
@@ -63,10 +62,6 @@ class MiniPlayer(Gtk.Bin, InfosController):
             @param button as Gtk.Button
             @param event as Gdk.Event
         """
-        # Remove this the day X11 is dead!
-        allocation = self.get_allocation()
-        if allocation.height < WindowSize.SMALL - 50:
-            return
         if Lp().player.current_track.id is not None:
             if event.button != 1 and Lp().player.current_track.id >= 0:
                 popover = TrackMenuPopover(
