@@ -40,6 +40,7 @@ class BinPlayer(BasePlayer):
         self._playbin = self._playbin1 = Gst.ElementFactory.make(
                                                            'playbin', 'player')
         self._playbin2 = Gst.ElementFactory.make('playbin', 'player')
+        self._preview = None
         self._plugins = self.plugins1 = PluginsPlayer(self._playbin1)
         self.plugins2 = PluginsPlayer(self._playbin2)
         self._volume_id = self._playbin.connect('notify::volume',
@@ -62,6 +63,27 @@ class BinPlayer(BasePlayer):
         self._handled_error = None
         self._start_time = 0
 
+    @property
+    def preview(self):
+        """
+            Get a preview bin
+            @return Gst.Element
+        """
+        if self._preview is None:
+            self._preview = Gst.ElementFactory.make('playbin', 'player')
+            self.set_preview_output()
+        return self._preview
+
+    def set_preview_output(self):
+        """
+            Set preview output
+        """
+        if self._preview is not None:
+            output = Lp().settings.get_value('preview-output').get_string()
+            pulse = Gst.ElementFactory.make('pulsesink', 'output')
+            pulse.set_property('device', output)
+            self._preview.set_property('audio-sink', pulse)
+
     def is_playing(self):
         """
             True if player is playing
@@ -150,6 +172,8 @@ class BinPlayer(BasePlayer):
             Seek current track to position
             @param position as seconds
         """
+        if self.locked or self.current_track.id is None:
+            return
         # Seems gstreamer doesn't like seeking to end, sometimes
         # doesn't go to next track
         if position >= self.current_track.duration:
@@ -459,7 +483,10 @@ class BinPlayer(BasePlayer):
         if self._playbin.get_bus() == bus:
             self.stop()
             self._finished = NextContext.NONE
-            self._context.next = NextContext.NONE
+            if Lp().settings.get_value('repeat'):
+                self._context.next = NextContext.NONE
+            else:
+                self._context.next = NextContext.STOP_ALL
             if self._next_track.id is not None:
                 self._load_track(self._next_track)
             self.emit('current-changed')
