@@ -340,7 +340,7 @@ class Playlists(GObject.GObject):
         """
         # We do not use Album object for performance reasons
         playlist_paths = self.get_tracks(playlist_id)
-        track_paths = Lp().albums.get_tracks_path(album_id,
+        track_paths = Lp().albums.get_track_paths(album_id,
                                                   genre_ids,
                                                   artist_ids)
         return len(set(playlist_paths) & set(track_paths)) == len(track_paths)
