@@ -20,8 +20,9 @@ except:
 from gettext import gettext as _
 from threading import Thread
 from shutil import which
+from re import findall, DOTALL
 
-from lollypop.define import Lp, Type, SecretSchema, SecretAttributes
+from lollypop.define import Lp, SecretSchema, SecretAttributes
 from lollypop.cache import InfoCache
 
 
@@ -133,9 +134,11 @@ class SettingsDialog:
         switch_repeat = builder.get_object('switch_repeat')
         switch_repeat.set_state(not Lp().settings.get_value('repeat'))
 
-        combo_orderby = builder.get_object('orderby')
+        combo_orderby = builder.get_object('combo_orderby')
         combo_orderby.set_active(Lp().settings.get_enum(('orderby')))
 
+        combo_preview = builder.get_object('combo_preview')
+
         scale_coversize = builder.get_object('scale_coversize')
         scale_coversize.set_range(150, 300)
         scale_coversize.set_value(
@@ -146,7 +149,8 @@ class SettingsDialog:
 
         main_chooser_box = builder.get_object('main_chooser_box')
         self._chooser_box = builder.get_object('chooser_box')
-        party_grid = builder.get_object('party_grid')
+
+        self._set_outputs(combo_preview)
 
         #
         # Music tab
@@ -174,37 +178,6 @@ class SettingsDialog:
             self._add_chooser(directory)
 
         #
-        # Party mode tab
-        #
-        genres = Lp().genres.get()
-        genres.insert(0, (Type.POPULARS, _("Populars")))
-        genres.insert(1, (Type.RECENTS, _("Recently added")))
-        ids = Lp().player.get_party_ids()
-        i = 0
-        x = 0
-        for genre_id, genre in genres:
-            label = Gtk.Label()
-            label.set_property('margin-start', 10)
-            label.set_property('halign', Gtk.Align.START)
-            label.set_property('hexpand', True)
-            label.set_ellipsize(Pango.EllipsizeMode.END)
-            label.set_text(genre)
-            label.set_tooltip_text(genre)
-            label.show()
-            switch = Gtk.Switch()
-            if genre_id in ids:
-                switch.set_state(True)
-            switch.connect("state-set", self._party_switch_state, genre_id)
-            switch.set_property('margin-end', 50)
-            switch.show()
-            party_grid.attach(label, x, i, 1, 1)
-            party_grid.attach(switch, x+1, i, 1, 1)
-            if x == 0:
-                x += 2
-            else:
-                i += 1
-                x = 0
-        #
         # Last.fm tab
         #
         if Lp().lastfm is not None and Secret is not None:
@@ -230,6 +203,44 @@ class SettingsDialog:
 #######################
 # PRIVATE             #
 #######################
+    def _get_pa_outputs(self):
+        """
+            Get PulseAudio outputs
+            @return name/device as [(str, str)]
+        """
+        ret = []
+        argv = ["pacmd", "list-sinks", None]
+        try:
+            (s, out, err, e) = GLib.spawn_sync(None, argv, None,
+                                               GLib.SpawnFlags.SEARCH_PATH,
+                                               None)
+            string = out.decode('utf-8')
+            devices = findall('name: <([^>]*)>', string, DOTALL)
+            names = findall('device.description = "([^"]*)"', string, DOTALL)
+            for name in names:
+                ret.append((name, devices.pop(0)))
+        except Exception as e:
+            print("SettingsDialog::_get_pa_outputse()", e)
+        return ret
+
+    def _set_outputs(self, combo):
+        """
+            Set outputs in combo
+            @parma combo as Gtk.ComboxBoxText
+        """
+        current = Lp().settings.get_value('preview-output').get_string()
+        renderer = combo.get_cells()[0]
+        renderer.set_property('ellipsize', Pango.EllipsizeMode.END)
+        renderer.set_property('max-width-chars', 60)
+        outputs = self._get_pa_outputs()
+        if outputs:
+            for output in outputs:
+                combo.append(output[1], output[0])
+                if output[1] == current:
+                    combo.set_active_id(output[1])
+        else:
+            combo.set_sensitive(False)
+
     def _add_chooser(self, directory=None):
         """
             Add a new chooser widget
@@ -460,25 +471,6 @@ class SettingsDialog:
             Lp().window.update_db()
         Lp().window.update_view()
 
-    def _party_switch_state(self, widget, state, genre_id):
-        """
-            Update party ids when use change a switch in dialog
-            @param widget as Gtk.Switch
-            @param state as bool, genre id as int
-        """
-        ids = Lp().player.get_party_ids()
-        if state:
-            try:
-                ids.append(genre_id)
-            except:
-                pass
-        else:
-            try:
-                ids.remove(genre_id)
-            except:
-                pass
-        Lp().settings.set_value('party-ids',  GLib.Variant('ai', ids))
-
     def _show_mix_popover(self, widget):
         """
             Show mix popover
@@ -492,6 +484,26 @@ class SettingsDialog:
                 self._popover.add(self._popover_content)
             self._popover.show_all()
 
+    def _on_preview_changed(self, combo):
+        """
+            Update preview setting
+            @param combo as Gtk.ComboBoxText
+        """
+        Lp().settings.set_value('preview-output',
+                                GLib.Variant('s', combo.get_active_id()))
+        Lp().player.set_preview_output()
+
+    def _on_preview_query_tooltip(self, combo, x, y, keyboard, tooltip):
+        """
+            Show tooltip if needed
+            @param combo as Gtk.ComboBoxText
+            @param x as int
+            @param y as int
+            @param keyboard as bool
+            @param tooltip as Gtk.Tooltip
+        """
+        combo.set_tooltip_text(combo.get_active_text())
+
     def _on_mix_button_press(self, widget, event):
         """
             Show mix popover on long press
