@@ -49,7 +49,7 @@ class ArtistAlbumsView(LazyLoadingView):
         self._spinner.show()
 
         self._albumbox = Gtk.Grid()
-        self._albumbox.set_row_spacing(20)
+        self._albumbox.set_row_spacing(5)
         self._albumbox.set_property("orientation", Gtk.Orientation.VERTICAL)
         self._albumbox.show()
         self._viewport.add(self._albumbox)
@@ -98,7 +98,7 @@ class ArtistAlbumsView(LazyLoadingView):
             @return height as int
         """
         height = 0
-        for child in self._albumbox.get_children():
+        for child in self._get_children():
             height += child.requested_height
         return height
 
@@ -129,7 +129,7 @@ class ArtistAlbumsView(LazyLoadingView):
     def _get_children(self):
         """
             Return view children
-            @return [AlbumWidget]
+            @return [AlbumDetailedWidget]
         """
         children = []
         for child in self._albumbox.get_children():
