@@ -10,47 +10,54 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib, Pango
+from gi.repository import Gtk, GLib, Gdk, Pango, GObject
 
 from threading import Thread
 from cgi import escape
 from gettext import gettext as _
 
-from lollypop.define import Lp, Type, WindowSize
+from lollypop.define import Lp, Type, WindowSize, Loading
 from lollypop.cellrenderer import CellRendererAlbum
 from lollypop.widgets_track import TracksWidget, PlaylistRow
 from lollypop.objects import Track
 
 
-class PlaylistsWidget(Gtk.Bin):
+class PlaylistsWidget(Gtk.Grid):
     """
         Show playlist tracks/albums
     """
+    __gsignals__ = {
+        'populated': (GObject.SignalFlags.RUN_FIRST, None, ())
+    }
 
     def __init__(self, playlist_ids):
         """
             Init playlist Widget
             @param playlist ids as [int]
         """
-        Gtk.Bin.__init__(self)
+        Gtk.Grid.__init__(self)
+        self.set_row_spacing(5)
+        self.set_orientation(Gtk.Orientation.VERTICAL)
         self._playlist_ids = playlist_ids
-        self._tracks1 = []
-        self._tracks2 = []
+        self._tracks_left = []
+        self._tracks_right = []
         self._width = None
         self._orientation = None
-        self._stop = False
+        self._loading = Loading.NONE
         # Used to block widget2 populate while showing one column
-        self._locked_widget2 = True
+        self._locked_widget_right = True
 
         self._box = Gtk.Grid()
+        self._box.set_vexpand(True)
         self._box.set_column_homogeneous(True)
-        self._box.set_property('valign', Gtk.Align.START)
         self._box.show()
 
         self.connect('size-allocate', self._on_size_allocate)
 
-        self._tracks_widget_left = TracksWidget()
-        self._tracks_widget_right = TracksWidget()
+        self._tracks_widget_left = TracksWidget(True)
+        self._tracks_widget_left.set_vexpand(True)
+        self._tracks_widget_right = TracksWidget(True)
+        self._tracks_widget_right.set_vexpand(True)
         self._tracks_widget_left.connect('activated',
                                          self._on_activated)
         self._tracks_widget_right.connect('activated',
@@ -58,6 +65,11 @@ class PlaylistsWidget(Gtk.Bin):
         self._tracks_widget_left.show()
         self._tracks_widget_right.show()
 
+        self.drag_dest_set(Gtk.DestDefaults.DROP | Gtk.DestDefaults.MOTION,
+                           [], Gdk.DragAction.MOVE)
+        self.drag_dest_add_text_targets()
+        self.connect('drag-data-received', self._on_drag_data_received)
+
         self.add(self._box)
 
     def get_id(self):
@@ -106,7 +118,7 @@ class PlaylistsWidget(Gtk.Bin):
         """
         # We reset width here to allow size allocation code to run
         self._width = None
-        self._tracks1 = list(tracks)
+        self._tracks_left = list(tracks)
         GLib.idle_add(self._add_tracks,
                       tracks,
                       self._tracks_widget_left,
@@ -119,10 +131,10 @@ class PlaylistsWidget(Gtk.Bin):
             @param track position as int
             @thread safe
         """
-        self._tracks2 = list(tracks)
+        self._tracks_right = list(tracks)
         # If we are showing only one column, wait for widget1
         if self._orientation == Gtk.Orientation.VERTICAL and\
-           self._locked_widget2:
+           self._locked_widget_right:
             GLib.timeout_add(100, self.populate_list_right, tracks, pos)
         else:
             # We reset width here to allow size allocation code to run
@@ -143,7 +155,7 @@ class PlaylistsWidget(Gtk.Bin):
         """
             Stop loading
         """
-        self._stop = True
+        self._loading = Loading.STOP
 
     def append(self, track_id):
         """
@@ -157,7 +169,7 @@ class PlaylistsWidget(Gtk.Bin):
         self._update_position()
         self._update_headers()
         self._tracks_widget_left.update_indexes(1)
-        self._tracks_widget_right.update_indexes(len(self._tracks1) + 1)
+        self._tracks_widget_right.update_indexes(len(self._tracks_left) + 1)
 
     def remove(self, track_id):
         """
@@ -180,7 +192,8 @@ class PlaylistsWidget(Gtk.Bin):
             self._update_position()
             self._update_headers()
             self._tracks_widget_left.update_indexes(1)
-            self._tracks_widget_right.update_indexes(len(self._tracks1) + 1)
+            self._tracks_widget_right.update_indexes(
+                                                    len(self._tracks_left) + 1)
 
 #######################
 # PRIVATE             #
@@ -194,11 +207,17 @@ class PlaylistsWidget(Gtk.Bin):
             @param pos as int
             @param previous album id as int
         """
-        if not tracks or self._stop:
+        if self._loading == Loading.STOP:
+            self._loading = Loading.NONE
+            return
+        if not tracks:
             if widget == self._tracks_widget_right:
-                self._stop = False
-            else:
-                self._locked_widget2 = False
+                self._loading |= Loading.RIGHT
+            elif widget == self._tracks_widget_left:
+                self._loading |= Loading.LEFT
+            if self._loading == Loading.ALL:
+                self.emit('populated')
+            self._locked_widget_right = False
             return
 
         track = Track(tracks.pop(0))
@@ -215,32 +234,32 @@ class PlaylistsWidget(Gtk.Bin):
             Update tracks based on current widget
         """
         # Recalculate tracks
-        self._tracks1 = []
-        self._tracks2 = []
+        self._tracks_left = []
+        self._tracks_right = []
         for child in self._tracks_widget_left.get_children():
-            self._tracks1.append(child.get_id())
+            self._tracks_left.append(child.get_id())
         for child in self._tracks_widget_right.get_children():
-            self._tracks2.append(child.get_id())
+            self._tracks_right.append(child.get_id())
 
     def _update_position(self):
         """
             Update widget position
         """
-        len_tracks1 = len(self._tracks1)
-        len_tracks2 = len(self._tracks2)
+        len_tracks1 = len(self._tracks_left)
+        len_tracks2 = len(self._tracks_right)
         # Take first track from tracks2 and put it at the end of tracks1
         if len_tracks2 > len_tracks1:
-            src = self._tracks2[0]
-            if self._tracks1:
-                dst = self._tracks1[-1]
+            src = self._tracks_right[0]
+            if self._tracks_left:
+                dst = self._tracks_left[-1]
             else:
                 dst = -1
             self._move_track(dst, src, False)
         # Take last track of tracks1 and put it at the bottom of tracks2
         elif len_tracks1 - 1 > len_tracks2:
-            src = self._tracks1[-1]
-            if self._tracks2:
-                dst = self._tracks2[0]
+            src = self._tracks_left[-1]
+            if self._tracks_right:
+                dst = self._tracks_right[0]
             else:
                 dst = -1
             self._move_track(dst, src, True)
@@ -253,8 +272,8 @@ class PlaylistsWidget(Gtk.Bin):
         self._tracks_widget_left.update_headers()
         prev_album_id = None
         if self._orientation == Gtk.Orientation.VERTICAL:
-            if self._tracks1:
-                prev_album_id = Track(self._tracks1[-1]).album.id
+            if self._tracks_left:
+                prev_album_id = Track(self._tracks_left[-1]).album.id
         self._tracks_widget_right.update_headers(prev_album_id)
 
     def _move_track(self, dst, src, up):
@@ -266,20 +285,20 @@ class PlaylistsWidget(Gtk.Bin):
             @return (dst_widget as TracksWidget,
                      src index as int, dst index as int)
         """
-        tracks1_len = len(self._tracks1)
-        tracks2_len = len(self._tracks2)
-        if src in self._tracks1:
+        tracks1_len = len(self._tracks_left)
+        tracks2_len = len(self._tracks_right)
+        if src in self._tracks_left:
             src_widget = self._tracks_widget_left
-            src_index = self._tracks1.index(src) - 1
+            src_index = self._tracks_left.index(src) - 1
         else:
             src_widget = self._tracks_widget_right
-            src_index = self._tracks2.index(src) - 1
-        if tracks1_len == 0 or dst in self._tracks1:
+            src_index = self._tracks_right.index(src) - 1
+        if tracks1_len == 0 or dst in self._tracks_left:
             dst_widget = self._tracks_widget_left
-            dst_tracks = self._tracks1
-        elif tracks2_len == 0 or dst in self._tracks2:
+            dst_tracks = self._tracks_left
+        elif tracks2_len == 0 or dst in self._tracks_right:
             dst_widget = self._tracks_widget_right
-            dst_tracks = self._tracks2
+            dst_tracks = self._tracks_right
         else:
             return
         # Remove src from src_widget
@@ -310,7 +329,7 @@ class PlaylistsWidget(Gtk.Bin):
                     src_track.album.artist_id not in src_track.artist_ids):
                 name = "<b>%s</b>\n%s" % (escape(", ".join(src_track.artists)),
                                           name)
-            self._tracks1.insert(index, src_track.id)
+            self._tracks_left.insert(index, src_track.id)
         row = PlaylistRow(src_track.id,
                           index,
                           index == 0 or
@@ -320,6 +339,28 @@ class PlaylistsWidget(Gtk.Bin):
         dst_widget.insert(row, index)
         return (src_widget, dst_widget, src_index, index)
 
+    def _on_drag_data_received(self, widget, context, x, y, data, info, time):
+        """
+            ONLY HAPPEN IN VERTICAL ORIENTATION
+            Horizontal orientation is handled by TracksWidget
+            @param widget as Gtk.Widget
+            @param context as Gdk.DragContext
+            @param x as int
+            @param y as int
+            @param data as Gtk.SelectionData
+            @param info as int
+            @param time as int
+        """
+        try:
+            try:
+                child = self._tracks_widget_right.get_children()[-1]
+            except:
+                child = self._tracks_widget_left.get_children()[-1]
+            self._on_track_moved(widget, child.get_id(),
+                                 int(data.get_text()), False)
+        except:
+            pass
+
     def _on_track_moved(self, widget, dst, src, up):
         """
             Move track from src to row
@@ -334,14 +375,15 @@ class PlaylistsWidget(Gtk.Bin):
             if len(self._playlist_ids) == 1 and self._playlist_ids[0] >= 0:
                 Lp().playlists.clear(self._playlist_ids[0], False)
                 tracks = []
-                for track_id in self._tracks1 + self._tracks2:
+                for track_id in self._tracks_left + self._tracks_right:
                     tracks.append(Track(track_id))
                 Lp().playlists.add_tracks(self._playlist_ids[0],
                                           tracks,
                                           False)
             if not (set(self._playlist_ids) -
                set(Lp().player.get_user_playlist_ids())):
-                Lp().player.update_user_playlist(self._tracks1 + self._tracks2)
+                Lp().player.update_user_playlist(self._tracks_left +
+                                                 self._tracks_right)
 
         (src_widget, dst_widget, src_index, dst_index) = \
             self._move_track(dst, src, up)
@@ -349,7 +391,7 @@ class PlaylistsWidget(Gtk.Bin):
         self._update_position()
         self._update_headers()
         self._tracks_widget_left.update_indexes(1)
-        self._tracks_widget_right.update_indexes(len(self._tracks1) + 1)
+        self._tracks_widget_right.update_indexes(len(self._tracks_left) + 1)
         t = Thread(target=update_playlist)
         t.daemon = True
         t.start()
@@ -365,8 +407,10 @@ class PlaylistsWidget(Gtk.Bin):
         self._width = allocation.width
         redraw = False
         if allocation.width < WindowSize.MONSTER:
+            self._box.set_property('valign', Gtk.Align.START)
             orientation = Gtk.Orientation.VERTICAL
         else:
+            self._box.set_property('valign', Gtk.Align.FILL)
             orientation = Gtk.Orientation.HORIZONTAL
         if orientation != self._orientation:
             self._orientation = orientation
@@ -395,8 +439,8 @@ class PlaylistsWidget(Gtk.Bin):
             Lp().player.load(Track(track_id))
             if not Lp().player.is_party():
                 Lp().player.populate_user_playlist_by_tracks(
-                                                            self._tracks1 +
-                                                            self._tracks2,
+                                                            self._tracks_left +
+                                                            self._tracks_right,
                                                             self._playlist_ids)
 
 
@@ -445,7 +489,9 @@ class PlaylistsManagerWidget(Gtk.Bin):
             renderer0 = Gtk.CellRendererToggle()
             renderer0.set_property('activatable', True)
             renderer0.connect('toggled', self._on_playlist_toggled)
-            column0 = Gtk.TreeViewColumn("toggle", renderer0, active=0)
+            column0 = Gtk.TreeViewColumn(" ✓", renderer0, active=0)
+            column0.set_clickable(True)
+            column0.connect('clicked', self._on_column0_clicked)
 
         renderer1 = Gtk.CellRendererText()
         renderer1.set_property('ellipsize-set', True)
@@ -454,12 +500,12 @@ class PlaylistsManagerWidget(Gtk.Bin):
         renderer1.connect('edited', self._on_playlist_edited)
         renderer1.connect('editing-started', self._on_playlist_editing_start)
         renderer1.connect('editing-canceled', self._on_playlist_editing_cancel)
-        column1 = Gtk.TreeViewColumn('text', renderer1, text=1)
+        column1 = Gtk.TreeViewColumn(_("Playlists"), renderer1, text=1)
         column1.set_sizing(Gtk.TreeViewColumnSizing.FIXED)
         column1.set_expand(True)
 
         renderer2 = Gtk.CellRendererPixbuf()
-        column2 = Gtk.TreeViewColumn('delete', renderer2)
+        column2 = Gtk.TreeViewColumn('', renderer2)
         column2.add_attribute(renderer2, 'icon-name', 2)
         column2.set_sizing(Gtk.TreeViewColumnSizing.FIXED)
         column2.set_property('fixed_width', 50)
@@ -570,7 +616,7 @@ class PlaylistsManagerWidget(Gtk.Bin):
         """
         iterator = self._model.get_iter(path)
         if iterator:
-            if column.get_title() == "delete":
+            if column.get_title() == '':
                 self._show_infobar(path)
 
     def _on_delete_confirm(self, button):
@@ -668,6 +714,19 @@ class PlaylistsManagerWidget(Gtk.Bin):
         # FIXME Not needed with GTK >= 3.18
         Lp().window.enable_global_shorcuts(True)
 
+    def _on_column0_clicked(self, column):
+        """
+            Select/Unselect all playlists checkboxes
+            @param column as Gtk.TreeViewColumn
+        """
+        selected = False
+        for item in self._model:
+            if item[0]:
+                selected = True
+        for item in self._model:
+            item[0] = not selected
+            self._set_current_object(item[3], item[0])
+
 
 class PlaylistEditWidget(Gtk.Bin):
     """
