@@ -36,6 +36,7 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
         self._name = name
         self._cover = None
         self._lock_overlay = False
+        self._show_overlay = False
         self._radios_manager = radios_manager
 
     def populate(self):
@@ -151,12 +152,14 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
             self._overlay.get_style_context().remove_class(
                                                     'cover-frame-selected')
 
-    def show_overlay(self, set):
+    def _show_overlay_func(self, set):
         """
             Set overlay
             @param set as bool
         """
-        if self._lock_overlay or self._show_overlay == set:
+        if self._lock_overlay or\
+           self._show_overlay == set or\
+           (set is True and Lp().player.locked):
             return
         if set:
             # Play button
@@ -194,9 +197,9 @@ class RadioWidget(Gtk.FlowBoxChild, AlbumWidget):
             self._overlay.add_overlay(self._play_event)
             self._overlay.add_overlay(self._artwork_event)
             self._overlay.show_all()
-            AlbumWidget.show_overlay(self, True)
+            AlbumWidget._show_overlay_func(self, True)
         else:
-            AlbumWidget.show_overlay(self, False)
+            AlbumWidget._show_overlay_func(self, False)
             self._play_event.destroy()
             self._play_event = None
             self._play_button.destroy()
